==> idb_shim-0.8.0.tar.gz: lib/idb_browser.dart <==
library idb_shim_browser;

import 'package:idb_shim/idb_client_native.dart';
import 'package:idb_shim/idb_client_websql.dart';
import 'package:idb_shim/idb_client_sembast.dart';
import 'package:sembast/sembast_memory.dart' as sembast;
import 'package:idb_shim/idb_client.dart';

IdbFactory getIdbFactory([String name]) {
  if (name == null) {
    name = IDB_FACTORY_BROWSER;
  }
  switch (name) {
    case IDB_FACTORY_BROWSER:
      return idbBrowserFactory;
    case IDB_FACTORY_PERSISTENT:
      return idbPersistentFactory;
    case IDB_FACTORY_NATIVE:
      return idbNativeFactory;
    case IDB_FACTORY_WEBSQL:
      return idbWebSqlFactory;
    case IDB_FACTORY_MEMORY:
      return idbMemoryFactory;
    case IDB_FACTORY_SEMBAST_MEMORY:
      return idbSembastMemoryFactory;
    default:
      throw new UnsupportedError("Factory '$name' not supported");
  }
}

IdbFactory get idbWebSqlFactory {
  if (IdbWebSqlFactory.supported) {
    return new IdbWebSqlFactory();
  } else {
    return null;
  }
}

IdbFactory get idbNativeFactory {
  if (IdbNativeFactory.supported) {
    return new IdbNativeFactory();
  } else {
    return null;
  }
}

IdbFactory get idbMemoryFactory => idbSembastMemoryFactory;

IdbFactory _idbSembastMemoryFactory;
IdbFactory get idbSembastMemoryFactory {
  if (_idbSembastMemoryFactory == null) {
    _idbSembastMemoryFactory = new IdbSembastFactory(sembast.memoryDatabaseFactory, null);
  }
  return _idbSembastMemoryFactory;
}

/**
 * Use either native (indexeddb) or websql implementation
 * This means that the memory implementation won't be linked
 * if you use this function
 * This can return null;
 */
IdbFactory get idbPersistentFactory {
  IdbFactory idbFactory = idbNativeFactory;
  if (idbFactory == null) {
    idbFactory = idbWebSqlFactory;
  }
  return idbFactory;
}

/**
 * this use the best implementation available
 * defaulting to memory
 */
IdbFactory get idbBrowserFactory {
  IdbFactory idbFactory = idbPersistentFactory;
  if (idbFactory == null) {
    idbFactory = idbMemoryFactory;
  }
  return idbFactory;
}

==> idb_shim-1.0.0.tar.gz: lib/idb_browser.dart <==
library idb_shim_browser;

import 'package:idb_shim/idb_client_native.dart';
import 'package:idb_shim/idb_client_websql.dart';
import 'package:idb_shim/idb_client_sembast.dart';
import 'package:sembast/sembast_memory.dart' as sembast;
import 'package:idb_shim/idb_client.dart';

IdbFactory getIdbFactory([String name]) {
  if (name == null) {
    name = IDB_FACTORY_BROWSER;
  }
  switch (name) {
    case IDB_FACTORY_BROWSER:
      return idbBrowserFactory;
    case IDB_FACTORY_PERSISTENT:
      return idbPersistentFactory;
    case IDB_FACTORY_NATIVE:
      return idbNativeFactory;
    case IDB_FACTORY_WEBSQL:
      return idbWebSqlFactory;
    case IDB_FACTORY_MEMORY:
      return idbMemoryFactory;
    case IDB_FACTORY_SEMBAST_MEMORY:
      return idbSembastMemoryFactory;
    default:
      throw new UnsupportedError("Factory '$name' not supported");
  }
}

IdbFactory get idbWebSqlFactory {
  if (IdbWebSqlFactory.supported) {
    return new IdbWebSqlFactory();
  } else {
    return null;
  }
}

IdbFactory get idbNativeFactory {
  if (IdbNativeFactory.supported) {
    return new IdbNativeFactory();
  } else {
    return null;
  }
}

IdbFactory get idbMemoryFactory => idbSembastMemoryFactory;

IdbFactory _idbSembastMemoryFactory;
IdbFactory get idbSembastMemoryFactory {
  if (_idbSembastMemoryFactory == null) {
    _idbSembastMemoryFactory =
        new IdbSembastFactory(sembast.memoryDatabaseFactory, null);
  }
  return _idbSembastMemoryFactory;
}

/**
 * Use either native (indexeddb) or websql implementation
 * This means that the memory implementation won't be linked
 * if you use this function
 * This can return null;
 */
IdbFactory get idbPersistentFactory {
  IdbFactory idbFactory = idbNativeFactory;
  if (idbFactory == null) {
    idbFactory = idbWebSqlFactory;
  }
  return idbFactory;
}

/**
 * this use the best implementation available
 * defaulting to memory
 */
IdbFactory get idbBrowserFactory {
  IdbFactory idbFactory = idbPersistentFactory;
  if (idbFactory == null) {
    idbFactory = idbMemoryFactory;
  }
  return idbFactory;
}
